@@ -401,8 +401,9 @@ def show_release(ctx, release_id):
 
 @cli.command()
 @click.argument('release_id', required=False)
+@click.option('--limit', required=False, default=10)
 @click.pass_context
-def show_deployments(ctx, release_id):
+def show_deployments(ctx, release_id, limit):
     project = ctx.obj['project']
 
     rows = []
@@ -415,7 +416,7 @@ def show_deployments(ctx, release_id):
         "description"
     ]
 
-    for deployment in project.get_deployments(release_id=release_id):
+    for deployment in project.get_deployments(release_id=release_id, limit=limit):
         rows.append(
             [
                 deployment["release_id"],
